@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Prereqs::EnsureCoreOrPP;
 
-our $DATE = '2015-10-03'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2016-02-14'; # DATE
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 use strict;
@@ -26,8 +26,10 @@ sub setup_installer {
     my $res = call_lcpan_script(argv=>[
         "deps", "-R",
         grep {$_ ne 'perl'} keys %$rr_prereqs]);
+    $self->log_fatal(["Can't lcpan deps: %s - %s", $res->[0], $res->[1]])
+        unless $res->[0] == 200;
     my $has_err;
-    for my $entry (@$res) {
+    for my $entry (@{$res->[2]}) {
         my $mod = $entry->{module};
         $mod =~ s/^\s+//;
         if (!module_path(module=>$mod)) {
@@ -60,7 +62,7 @@ Dist::Zilla::Plugin::Prereqs::EnsureCoreOrPP - Make sure that prereqs (and their
 
 =head1 VERSION
 
-This document describes version 0.07 of Dist::Zilla::Plugin::Prereqs::EnsureCoreOrPP (from Perl distribution Dist-Zilla-Plugin-Prereqs-EnsureCoreOrPP), released on 2015-10-03.
+This document describes version 0.08 of Dist::Zilla::Plugin::Prereqs::EnsureCoreOrPP (from Perl distribution Dist-Zilla-Plugin-Prereqs-EnsureCoreOrPP), released on 2016-02-14.
 
 =head1 SYNOPSIS
 
@@ -85,18 +87,6 @@ because I don't always use "dzil release" (i.e. during offline deployment, I
 
 =for Pod::Coverage .+
 
-=head1 SEE ALSO
-
-L<App::FatPacker>, L<App::depak>
-
-L<Dist::Zilla::Plugin::Prereqs::EnsurePP>
-
-Related plugins: L<Dist::Zilla::Plugin::CheckPrereqsIndexed>,
-L<Dist::Zilla::Plugin::EnsurePrereqsInstalled>,
-L<Dist::Zilla::Plugin::OnlyCorePrereqs>
-
-L<App::lcpan>, L<lcpan>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla-Plugin-Prereqs-EnsureCoreOrPP>.
@@ -113,13 +103,25 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<App::FatPacker>, L<App::depak>
+
+L<Dist::Zilla::Plugin::Prereqs::EnsurePP>
+
+Related plugins: L<Dist::Zilla::Plugin::CheckPrereqsIndexed>,
+L<Dist::Zilla::Plugin::EnsurePrereqsInstalled>,
+L<Dist::Zilla::Plugin::OnlyCorePrereqs>
+
+L<App::lcpan>, L<lcpan>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
